Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( FlowdockRobotName string = "Flowbot" FlowdockChatUrl string = "https://api.flowdock.com/v1/messages/chat/" FlowdockInboxUrl string = "https://api.flowdock.com/v1/messages/team_inbox/" FlowdockStreamUrl string FlowdockFlowToken string FlowdockAuthUsername string FlowdockAuthPassword string )
Flowdock configuration values
Functions ¶
func SendThreadChat ¶
Send a chat message to a thread
Types ¶
type Chat ¶
type Chat struct {
Content string `json:"content"`
ExternalUserName string `json:"external_user_name"`
ThreadId string `json:"thread_id,omitempty"`
}
A Flowdock chat message
type Command ¶
A command structure Streaming API will detect this command name on Flow and run the command handler
type Entry ¶
type Entry struct {
Event string `json:"event"`
Tags []string `json:"tags"`
Uuid string `json:"uuid"`
Persist bool `json:"persist"`
Id int `json:"id"`
Flow string `json:"flow"`
Content string `json:"content"`
Sent int `json:"sent"`
App string `json:"app"`
CreatedAt time.Time `json:"created_at"`
Attachments []string `json:"attachments"`
User string `json:"user"`
ThreadId string `json:"thread_id,omitempty"`
}
A Flowdock entry structure Each streamed response will be transformed into an event
Click to show internal directories.
Click to hide internal directories.